==> django-froala-editor-1.2.3.tar.gz: django-froala-editor-1.2.3/froala_editor/static/froala_editor/js/langs/hr.js <==
/*!
 * froala_editor v1.2.3 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Croatian.
 */

$.Editable.LANGS['hr'] = {
  translation: {
    "Bold": "Masna",
    "Italic": "Kurziv",
    "Underline": "Crta ispod",
    "Strikethrough": "Crta kroz sredinu",
    "Font Size": "Veli\u010dina fonta",
    "Color": "Boja",
    "Background": "Pozadine",
    "Text": "Teksta",
    "Format Block": "Formatiranje bloka",
    "Normal": "Normalno",
    "Paragraph": "Paragraf",
    "Code": "Izvorni kod",
    "Quote": "Citat",
    "Heading 1": "Zaglavlje 1",
    "Heading 2": "Zaglavlje 2",
    "Heading 3": "Zaglavlje 3",
    "Heading 4": "Zaglavlje 4",
    "Heading 5": "Zaglavlje 5",
    "Heading 6": "Zaglavlje 6",
    "Block Style": "Blokiranje stil",
    "Alignment": "Poravnanje",
    "Align Left": "Poravnaj lijevo",
    "Align Center": "Poravnaj po sredini",
    "Align Right": "Poravnaj desno",
    "Justify": "Obostrano poravnanje",
    "Numbered List": "Numerirana lista",
    "Bulleted List": "Lista bez reda",
    "Indent Less": "Uvuci paragraf",
    "Indent More": "Izvuci paragraf",
    "Select All": "Sa\u010duvaj sve",
    "Insert Link": "Umetni link",
    "Insert Image": "Umetni sliku",
    "Insert Video": "Umetni video",
    "Undo": "Korak nazad",
    "Redo": "Korak naprijed",
    "Show HTML": "Prika\u017ei HTML kod",
    "Float Left": "Prebaci lijevo",
    "Float None": "Bez prebacivanja",
    "Float Right": "Prebaci desno",
    "Replace Image": "Zamijeni sliku",
    "Remove Image": "Ukloni sliku",
    "Title": "Naslov",
    "Drop image": "Izbaci sliku",
    "or click": "ili odaberi",
    "or": "ili",
    "Enter URL": "Enter URL",
    "Please wait!": "Molim sa\u010dekaj.",
    "Are you sure? Image will be deleted.": "Da li ste sigurni da \u017eelite da obri\u0161ete ovu sliku?",
    "UNLINK": "Ukloni link",
    "Open in new tab": "Otvori u novom prozoru",
    "Type something": "Ukucajte ne\u0161tp",
    "Cancel": "Otka\u017ei",
    "OK": "U redu",
    "Manage images": "Upravljanje slike",
    "Delete": "Obri\u0161i",
    "Font Family": "Odaberi font",
    "Insert Horizontal Line": "Umetni liniju",
    "Table": "Tabela",
    "Insert table": "Umetni tabelu",
    "Cell": "Polje",
    "Row": "Red",
    "Column": "Stupac",
    "Delete table": "Obri\u0161i tabelu",
    "Insert cell before": "Umetni polje prije",
    "Insert cell after": "Umetni polje posle",
    "Delete cell": "Obri\u0161i polje",
    "Merge cells": "Spoji polja",
    "Horizontal split": "Horizontalno razdvajanje polja",
    "Vertical split": "Vertikalno razdvajanje polja",
    "Insert row above": "Umetni red iznad",
    "Insert row below": "Umetni red ispod",
    "Delete row": "Obri\u0161i red",
    "Insert column before": "Umetni stupac prije",
    "Insert column after": "Umetni stupac poslije",
    "Delete column": "Obri\u0161i stupac"
  },
  direction: "ltr"
};

==> django-froala-editor-1.2.4.tar.gz: django-froala-editor-1.2.4/froala_editor/static/froala_editor/js/langs/hr.js <==
/*!
 * froala_editor v1.2.4 (http://editor.froala.com)
 * Copyright 2014-2014 Froala
 */

/**
 * Croatian.
 */

$.Editable.LANGS['hr'] = {
  translation: {
    "Bold": "Podebljaj",
    "Italic": "Kurziv",
    "Underline": "Crta ispod",
    "Strikethrough": "Crta kroz sredinu",
    "Font Size": "Veli\u010dina fonta",
    "Color": "Boja",
    "Background": "Pozadine",
    "Text": "Teksta",
    "Format Block": "Format bloka",
    "Normal": "Normalno",
    "Paragraph": "Paragraf",
    "Code": "Izvorni kod",
    "Quote": "Citat",
    "Heading 1": "Zaglavlje 1",
    "Heading 2": "Zaglavlje 2",
    "Heading 3": "Zaglavlje 3",
    "Heading 4": "Zaglavlje 4",
    "Heading 5": "Zaglavlje 5",
    "Heading 6": "Zaglavlje 6",
    "Block Style": "Blokiranje stil",
    "Alignment": "Poravnanje",
    "Align Left": "Poravnaj lijevo",
    "Align Center": "Poravnaj po sredini",
    "Align Right": "Poravnaj desno",
    "Justify": "Obostrano poravnanje",
    "Numbered List": "Numerirana lista",
    "Bulleted List": "Lista bez reda",
    "Indent Less": "Uvuci paragraf",
    "Indent More": "Izvuci paragraf",
    "Select All": "Sa\u010duvaj sve",
    "Insert Link": "Umetni link",
    "Insert Image": "Umetni sliku",
    "Insert Video": "Umetni video",
    "Undo": "Korak natrag",
    "Redo": "Korak naprijed",
    "Show HTML": "Prika\u017ei HTML kod",
    "Float Left": "Prebaci lijevo",
    "Float None": "Bez prebacivanja",
    "Float Right": "Prebaci desno",
    "Replace Image": "Zamijeni sliku",
    "Remove Image": "Ukloni sliku",
    "Title": "Naslov",
    "Drop image": "Izbaci sliku",
    "or click": "ili odaberi",
    "or": "ili",
    "Enter URL": "Enter URL",
    "Please wait!": "Molim pri\u010dekaj!",
    "Are you sure? Image will be deleted.": "Da li ste sigurni da \u017eelite obrisati ovu sliku?",
    "UNLINK": "Ukloni link",
    "Open in new tab": "Otvori u novom prozoru",
    "Type something": "Ukucaj ne\u0161to",
    "Cancel": "Otka\u017ei",
    "OK": "U redu",
    "Manage images": "Upravljanje slike",
    "Delete": "Obri\u0161i",
    "Font Family": "Odaberi font",
    "Insert Horizontal Line": "Umetni liniju",
    "Table": "Tablica",
    "Insert table": "Umetni tablicu",
    "Cell": "Polje",
    "Row": "Red",
    "Column": "Stupac",
    "Delete table": "Obri\u0161i tablicu",
    "Insert cell before": "Umetni polje prije",
    "Insert cell after": "Umetni polje poslije",
    "Delete cell": "Obri\u0161i polje",
    "Merge cells": "Spoji polja",
    "Horizontal split": "Horizontalno razdvajanje polja",
    "Vertical split": "Vertikalno razdvajanje polja",
    "Insert row above": "Umetni red iznad",
    "Insert row below": "Umetni red ispod",
    "Delete row": "Obri\u0161i red",
    "Insert column before": "Umetni stupac prije",
    "Insert column after": "Umetni stupac poslije",
    "Delete column": "Obri\u0161i stupac",
    "Uploading image": "Prijenos slike",
    "Upload File": "Prijenos datoteke",
    "Drop File": "Izbaci datoteke",
    "Clear formatting": "Ukloniti oblikovanje"
  },
  direction: "ltr"
};
